[webkit-changes] cvs commit: SVGSupport/ksvg2/svg
SVGStyledElementImpl.cpp
Eric
eseidel at opensource.apple.com
Sun Oct 2 23:21:42 PDT 2005
eseidel 05/10/02 23:21:41
Modified: . ChangeLog
ksvg2/svg SVGStyledElementImpl.cpp
Log:
Bug #: 5209
Submitted by: eseidel
Reviewed by: darin
Closes large memory leak in KSVG.
http://bugzilla.opendarwin.org/show_bug.cgi?id=5209
* ksvg2/svg/SVGStyledElementImpl.cpp:
(SVGStyledElementImpl::attach): delete orphans unless PatternImpl
Revision Changes Path
1.185 +10 -0 WebCore/ChangeLog
Index: ChangeLog
===================================================================
RCS file: /cvs/root/WebCore/ChangeLog,v
retrieving revision 1.184
retrieving revision 1.185
diff -u -r1.184 -r1.185
--- ChangeLog 3 Oct 2005 06:15:04 -0000 1.184
+++ ChangeLog 3 Oct 2005 06:21:36 -0000 1.185
@@ -1,5 +1,15 @@
2005-10-02 Eric Seidel <eseidel at apple.com>
+ Reviewed by darin.
+
+ Closes large memory leak in KSVG.
+ http://bugzilla.opendarwin.org/show_bug.cgi?id=5209
+
+ * ksvg2/svg/SVGStyledElementImpl.cpp:
+ (SVGStyledElementImpl::attach): delete orphans unless PatternImpl
+
+2005-10-02 Eric Seidel <eseidel at apple.com>
+
Reviewed by mjs.
Fixes SVG animation support in Safari/WebKit.
1.8 +5 -3 SVGSupport/ksvg2/svg/SVGStyledElementImpl.cpp
Index: SVGStyledElementImpl.cpp
===================================================================
RCS file: /cvs/root/SVGSupport/ksvg2/svg/SVGStyledElementImpl.cpp,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- SVGStyledElementImpl.cpp 28 Sep 2005 05:06:08 -0000 1.7
+++ SVGStyledElementImpl.cpp 3 Oct 2005 06:21:41 -0000 1.8
@@ -231,9 +231,11 @@
styledParent = static_cast<SVGStyledElementImpl *>(parentElement);
if(styledParent && styledParent->canvasItem() && styledParent->allowAttachChildren(this))
styledParent->canvasItem()->appendItem(m_canvasItem);
- else if (styledParent) {
- // FIXME: This exists until we can find a better way to create the root node. -- ecs 8/7/05
- fprintf(stderr, "FAILED CANVAS INSERTION: <%s>, leaking %p\n", KDOM::DOMString(nodeName()).string().ascii(), this);
+ else if (styledParent && (styledParent->id() != ID_PATTERN)) {
+ // FIXME: This exists until we can find a better way to create root && pattern nodes. -- ecs 8/7/05
+ delete m_canvasItem;
+ m_canvasItem = NULL;
+ //fprintf(stderr, "FAILED CANVAS INSERTION: <%s>\n", KDOM::DOMString(nodeName()).string().ascii())
}
#ifndef APPLE_COMPILE_HACK
More information about the webkit-changes
mailing list